import React from 'react';
import {View, StyleSheet, Image, Text} from 'react-native';
import Button from '../../components/Button';
import Input from '../../components/Input';
import LoadingActivity from '../../components/LoadingActivity';
import Constants from '../../lib/constants';
import Errors from '../../lib/errors';
import User from '../../services/User';

class Login extends React.Component {
  state = {
    email: '',
    password: '',
    loginErrorMessage: '',
    loading: false
  }

  render() {
    return (
      <View style={styles.container}>
        <Image
          source={require('../../assets/logo.png')}
          resizeMode="contain"
          style={styles.logo}
        />
        {this.loginActions}
      </View>
    );
  }

  onChangeTextEmail = (email) => {
    this.setState({
      email: email
    });
  }

  onChangeTextPassword = (password) => {
    this.setState({
      password: password
    });
  }

  setErrorMessage = (msg) => {
    this.setState({
      loginErrorMessage: Errors[msg] || msg
    });
  }

  clearErrorMessage = () => {
    this.setState({
      loginErrorMessage: ''
    });
  }

  setLoading = (isLoading) => {
    this.setState({
      loading: isLoading
    });
  }

  onLogin = () => {
    this.setLoading(true);
    this.clearErrorMessage();
    User.login(this.state.email, this.state.password).then(() => {
      this.props.navigation.navigate('Trainings');
    }).catch(e => {
      this.setErrorMessage(e.code);
    }).finally(() => {
      this.setLoading(false);
    });
  }

  get loginActions() {
    return (
      <View style={styles.actionsContainer}>
        <View style={styles.formContainer}>
          <Input placeholder="Digite seu email" autoCompleteType='email' keyboardType='email-address' onChangeText={this.onChangeTextEmail} />
          <Input placeholder="Digite sua senha" secureTextEntry textContentType
          ='password' onChangeText={this.onChangeTextPassword} />
          <Text style={styles.loginError}>{this.state.loginErrorMessage}</Text>
        </View>
        <View style={styles.submitContainer}>
          <Button onPress={this.onLogin}>Entrar</Button>
        </View>
        <LoadingActivity loading={this.state.loading} />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    backgroundColor: Constants.colors.primary,
    flex: 1,
    alignItems: 'center',
  },
  logo: {
    height: 200,
  },
  actionsContainer: {
    backgroundColor: 'white',
    width: '85%',
    borderRadius: 15,
    height: 300,
    marginBottom: 150,
    alignItems: 'center',
    paddingVertical: 50,
  },
  formContainer: {
    flex: 3,
    justifyContent: 'space-around',
  },
  submitContainer: {
    flex: 1,
    marginTop: 20,
    justifyContent: 'center',
  },
  loginError: {
    color: 'red',
    width: 240,
    textAlign: 'center',
    marginTop: 6
  }
});

export default Login;
